@@ -1,4 +1,4 @@
-from .base_atari_env import BaseAtariEnv, base_env_wrapper_fn
+from .base_atari_env import BaseAtariEnv, base_env_wrapper_fn, parallel_wrapper_fn
 
 
 def raw_env(num_players=4, **kwargs):
@@ -9,3 +9,4 @@ def raw_env(num_players=4, **kwargs):
 
 
 env = base_env_wrapper_fn(raw_env)
+parallel_env = parallel_wrapper_fn(env)
