@@ -16,7 +16,7 @@ def test_save_obs(env):
     env.reset()
     try:
         check_save_obs(env)
-        for agent in env.agent_iter(env.num_agents):
+        for agent in env.agents:
             save_observation(env=env, agent=agent, save_dir="saved_observations")
 
     except AssertionError as ae:
